@@ -32,7 +32,8 @@ import logging
 logger = logging.getLogger('openleadr')
 
 SIGNER = XMLSigner(method=methods.detached,
-                   c14n_algorithm="http://www.w3.org/2001/10/xml-exc-c14n#")
+                   c14n_algorithm="http://www.w3.org/TR/2001/REC-xml-c14n-20010315")
+SIGNER.namespaces['oadr'] = "http://openadr.org/oadr-2.0b/2012/07"
 VERIFIER = XMLVerifier()
 
 XML_SCHEMA_LOCATION = os.path.join(os.path.dirname(__file__), 'schema', 'oadr_20b.xsd')
@@ -85,16 +86,21 @@ def validate_xml_schema(content):
     """
     Validates the XML tree against the schema. Return the XML tree.
     """
-    try:
-        tree = etree.fromstring(content, XML_PARSER)
-    except Exception:
-        logger.warning("XML Validation error in incoming message")
-    else:
-        return tree
+    tree = etree.fromstring(content, XML_PARSER)
+    return tree
 
 
-def validate_xml_signature(xml_tree):
+def validate_xml_signature(xml_tree, cert_fingerprint=None):
+    """
+    Validate the XMLDSIG signature and the ReplayProtect element.
+    """
     cert = utils.extract_pem_cert(xml_tree)
+    if cert_fingerprint:
+        fingerprint = utils.certificate_fingerprint(cert)
+        if fingerprint != cert_fingerprint:
+            raise errors.FingerprintMismatch("The certificate fingerprint was incorrect. "
+                                             f"Expected: {cert_fingerprint};"
+                                             f"Received: {fingerprint}")
     VERIFIER.verify(xml_tree, x509_cert=utils.ensure_bytes(cert), expect_references=2)
     _verify_replay_protect(xml_tree)
 
