@@ -76,12 +76,13 @@ class ReportService(VTNService):
         """
         report_requests = []
         args = inspect.signature(self.on_register_report).parameters
-        if all(['measurement' in args, 'resource_id' in args,
+        if all(['ven_id' in args, 'resource_id' in args, 'measurement' in args,
                 'min_sampling_interval' in args, 'max_sampling_interval' in args,
                 'unit' in args, 'scale' in args]):
             for report in payload['reports']:
                 if report['report_name'] == 'METADATA_TELEMETRY_STATUS':
-                    result = [self.on_register_report(resource_id=rd['report_subject']['resource_id'],
+                    result = [self.on_register_report(ven_id=payload['ven_id'],
+                                                      resource_id=rd['report_subject']['resource_id'],
                                                       measurement='Status',
                                                       unit=None,
                                                       scale=None,
@@ -89,7 +90,8 @@ class ReportService(VTNService):
                                                       max_sampling_interval=rd['sampling_rate']['max_period'])
                               for rd in report['report_descriptions']]
                 elif report['report_name'] == 'METADATA_TELEMETRY_USAGE':
-                    result = [self.on_register_report(resource_id=rd['report_subject']['resource_id'],
+                    result = [self.on_register_report(ven_id=payload['ven_id'],
+                                                      resource_id=rd['report_subject']['resource_id'],
                                                       measurement=rd['measurement']['item_description'],
                                                       unit=rd['measurement']['item_units'],
                                                       scale=rd['measurement']['si_scale_code'],
@@ -175,11 +177,11 @@ class ReportService(VTNService):
         to allow for requesting the offered reports.
         """
         logger.warning("You should implement and register your own on_register_report handler "
-                       "if you want to receive reports from a VEN. This handler will receive an "
-                       "oadrReport descriptor, and should return a list of"
-                       "(r_id, callback, sampling_interval) "
-                       "tuples for the report segments you wish to receive. "
-                       "Not requesting any reports at this moment.")
+                       "if you want to receive reports from a VEN. This handler will receive the "
+                       "following arguments: ven_id, resource_id, measurement, unit, scale, "
+                       "min_sampling_interval, max_sampling_interval and should return either "
+                       "None or (callback, sampling_interval) or "
+                       "(callback, sampling_interval, reporting_interval).")
         return None
 
     @handler('oadrUpdateReport')
