@@ -25,7 +25,7 @@ from signxml.exceptions import InvalidSignature
 from .. import errors
 from ..enums import STATUS_CODES
 from ..messaging import parse_message, validate_xml_schema, authenticate_message
-from ..utils import generate_id
+from ..utils import generate_id, get_cert_fingerprint_from_request
 
 from dataclasses import is_dataclass, asdict
 
@@ -59,6 +59,9 @@ class VTNService:
 
             # Pass the message off to the handler and get the response type and payload
             try:
+                # Add the request fingerprint to the message so that the handler can check for it.
+                if request.secure and message_type == 'oadrCreatePartyRegistration':
+                    message_payload['fingerprint'] = get_cert_fingerprint_from_request(request)
                 response_type, response_payload = await self.handle_message(message_type,
                                                                             message_payload)
             except Exception as err:
@@ -67,7 +70,7 @@ class VTNService:
                 raise err
 
             if 'response' not in response_payload:
-                response_payload['response'] = {'response_status': 200,
+                response_payload['response'] = {'response_code': 200,
                                                 'response_description': 'OK',
                                                 'request_id': message_payload.get('request_id')}
             response_payload['vtn_id'] = self.vtn_id
@@ -76,7 +79,7 @@ class VTNService:
         except errors.ProtocolError as err:
             # In case of an OpenADR error, return a valid OpenADR message
             response_type, response_payload = self.error_response(message_type,
-                                                                  err.response_status,
+                                                                  err.response_code,
                                                                   err.response_description)
             msg = self._create_message(response_type, **response_payload)
             response = web.Response(text=msg,
@@ -85,14 +88,14 @@ class VTNService:
         except errors.HTTPError as err:
             # If we throw a http-related error, deal with it here
             response = web.Response(text=err.response_description,
-                                    status=err.response_status)
+                                    status=err.response_code)
         except XMLSyntaxError as err:
             logger.warning(f"XML schema validation of incoming message failed: {err}.")
             response = web.Response(text=f'XML failed validation: {err}',
                                     status=HTTPStatus.BAD_REQUEST)
         except errors.FingerprintMismatch as err:
             logger.warning(err)
-            response = web.Response(text='Fingerprint mismatch',
+            response = web.Response(text=str(err),
                                     status=HTTPStatus.FORBIDDEN)
         except InvalidSignature:
             logger.warning("Incoming message had invalid signature, ignoring.")
